@@ -3,6 +3,7 @@ import pprint
 
 from spackle import log
 from spackle.exceptions import SpackleException
+from spackle.subscription import Subscription
 
 
 class Customer:
@@ -23,6 +24,10 @@ class Customer:
     def features(self):
         return self.data["features"]
 
+    @property
+    def subscriptions(self):
+        return [Subscription(s) for s in self.data["subscriptions"]]
+
     @property
     def flag_features(self):
         return [f for f in self.data["features"] if f["type"] == 0]
